EXPORTS
	??0CRemConTargetSelectorPlugin@@IAE@AAVMRemConTargetSelectorPluginObserver@@@Z @ 1 NONAME ; CRemConTargetSelectorPlugin::CRemConTargetSelectorPlugin(class MRemConTargetSelectorPluginObserver &)
	??0TBearerSecurity@@QAE@VTUid@@ABVTSecurityPolicy@@@Z @ 2 NONAME ; TBearerSecurity::TBearerSecurity(class TUid, class TSecurityPolicy const &)
	??0TClientInfo@@QAE@XZ @ 3 NONAME ; TClientInfo::TClientInfo(void)
	??1CRemConTargetSelectorPlugin@@UAE@XZ @ 4 NONAME ; CRemConTargetSelectorPlugin::~CRemConTargetSelectorPlugin(void)
	??1TBearerSecurity@@QAE@XZ @ 5 NONAME ; TBearerSecurity::~TBearerSecurity(void)
	??1TClientInfo@@QAE@XZ @ 6 NONAME ; TClientInfo::~TClientInfo(void)
	?BearerUid@TBearerSecurity@@QBE?AVTUid@@XZ @ 7 NONAME ; class TUid TBearerSecurity::BearerUid(void) const
	?IncomingCommandAddressed@MRemConTargetSelectorPluginObserver@@QAEXH@Z @ 8 NONAME ; void MRemConTargetSelectorPluginObserver::IncomingCommandAddressed(int)
	?Message@TClientInfo@@QAEAAVRMessage2@@XZ @ 9 NONAME ; class RMessage2 & TClientInfo::Message(void)
	?Message@TClientInfo@@QBEABVRMessage2@@XZ @ 10 NONAME ; class RMessage2 const & TClientInfo::Message(void) const
	?NewL@CRemConTargetSelectorPlugin@@SAPAV1@VTUid@@AAVMRemConTargetSelectorPluginObserver@@@Z @ 11 NONAME ; class CRemConTargetSelectorPlugin * CRemConTargetSelectorPlugin::NewL(class TUid, class MRemConTargetSelectorPluginObserver &)
	?Observer@CRemConTargetSelectorPlugin@@IAEAAVMRemConTargetSelectorPluginObserver@@XZ @ 12 NONAME ; class MRemConTargetSelectorPluginObserver & CRemConTargetSelectorPlugin::Observer(void)
	?OutgoingCommandAddressed@MRemConTargetSelectorPluginObserver@@QAEXH@Z @ 13 NONAME ; void MRemConTargetSelectorPluginObserver::OutgoingCommandAddressed(int)
	?OutgoingCommandPermitted@MRemConTargetSelectorPluginObserver@@QAEXH@Z @ 14 NONAME ; void MRemConTargetSelectorPluginObserver::OutgoingCommandPermitted(int)
	?ProcessId@TClientInfo@@QAEAAVTProcessId@@XZ @ 15 NONAME ; class TProcessId & TClientInfo::ProcessId(void)
	?ProcessId@TClientInfo@@QBE?AVTProcessId@@XZ @ 16 NONAME ; class TProcessId TClientInfo::ProcessId(void) const
	?SecureId@TClientInfo@@QAEAAVTSecureId@@XZ @ 17 NONAME ; class TSecureId & TClientInfo::SecureId(void)
	?SecureId@TClientInfo@@QBE?AVTSecureId@@XZ @ 18 NONAME ; class TSecureId TClientInfo::SecureId(void) const
	?SecurityPolicy@TBearerSecurity@@QBEABVTSecurityPolicy@@XZ @ 19 NONAME ; class TSecurityPolicy const & TBearerSecurity::SecurityPolicy(void) const
	?GetConnections@MRemConTargetSelectorPluginObserver@@QAEHAAV?$TSglQue@VTRemConAddress@@@@@Z @ 20 NONAME ; int MRemConTargetSelectorPluginObserver::GetConnections(class TSglQue<class TRemConAddress> &)
	?OutgoingResponsePermitted@MRemConTargetSelectorPluginObserver@@QAEXH@Z @ 21 NONAME ; void MRemConTargetSelectorPluginObserver::OutgoingResponsePermitted(int)
	?IncomingNotifyAddressed@MRemConTargetSelectorPluginObserver@@QAEXPAVTClientInfo@@H@Z @ 22 NONAME ; void MRemConTargetSelectorPluginObserver::IncomingNotifyAddressed(class TClientInfo *, int)
	?ReAddressNotifies@MRemConTargetSelectorPluginObserver@@QAEXXZ @ 23 NONAME ; void MRemConTargetSelectorPluginObserver::ReAddressNotifies(void)
	?OutgoingNotifyCommandAddressed@MRemConTargetSelectorPluginObserver@@QAEXPAVTRemConAddress@@H@Z @ 24 NONAME ; void MRemConTargetSelectorPluginObserver::OutgoingNotifyCommandAddressed(class TRemConAddress *, int)
	?OutgoingNotifyCommandPermitted@MRemConTargetSelectorPluginObserver@@QAEXH@Z @ 25 NONAME ; void MRemConTargetSelectorPluginObserver::OutgoingNotifyCommandPermitted(int)
	?IncomingCommandPermitted@MRemConTargetSelectorPluginObserver@@QAEXH@Z @ 26 NONAME ; void MRemConTargetSelectorPluginObserver::IncomingCommandPermitted(int)
	?IncomingNotifyPermitted@MRemConTargetSelectorPluginObserver@@QAEXH@Z @ 27 NONAME ; void MRemConTargetSelectorPluginObserver::IncomingNotifyPermitted(int)
	?SetLocalAddressedClient@MRemConTargetSelectorPluginObserver@@QAEHABVTUid@@ABVTClientInfo@@@Z @ 28 NONAME ; int MRemConTargetSelectorPluginObserver::SetLocalAddressedClient(class TUid const &, class TClientInfo const &)

